@@ -18,13 +18,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *****************************************************************************/
 
-/**
- *  \file   dic_internals.h
- *  \brief  Internal dictionary structures
- *  \author Antoine Fraboulet
- *  \date   2002
- */
-
 #ifndef _DIC_INTERNALS_H_
 #define _DIC_INTERNALS_H_
 
@@ -45,22 +38,6 @@
  *  ----------------
  */
 
-struct __attribute__ ((packed)) DicEdgeOld
-{
-    public:
-      uint32_t
-        ptr : 24,
-        term:  1,
-        last:  1,
-        fill:  1,
-        chr :  5;
-      bool operator==(const DicEdgeOld &iOther) const
-      {
-          return memcmp(this, &iOther, sizeof(*this)) == 0;
-      }
-};
-
-
 struct __attribute__ ((packed)) DicEdge
 {
     public:
@@ -75,6 +52,5 @@ struct __attribute__ ((packed)) DicEdge
       }
 };
 
-
 #endif /* _DIC_INTERNALS_H */
 
