@@ -285,134 +285,78 @@ void Header::read(istream &iStream)
 
     m_version = aHeader.version;
 
+    // Version 0 corresponds to the dictionary format in the first Eliot
+    // versions, supported until Eliot 1.8 (excluded).
+    // The new version (version 1) was introduced in Eliot 1.6.
+    if (m_version == 0)
+    {
+        throw DicException(_("Too old dictionary format. This format is not "
+                             "supported anymore since Eliot 1.8. You can "
+                             "create dictionaries in the new format with the "
+                             "'compdic' tool provided with Eliot (since "
+                             "version 1.6)."));
+    }
+
     // Handle endianness
-    if (m_version == 0)
-    {
-#if defined(WORDS_BIGENDIAN)
-        aHeader.root       = swap4(aHeader.root);
-        aHeader.nwords     = swap4(aHeader.nwords);
-        aHeader.nodesused  = swap4(aHeader.nodesused);
-        aHeader.edgesused  = swap4(aHeader.edgesused);
-        aHeader.nodessaved = swap4(aHeader.nodessaved);
-        aHeader.edgessaved = swap4(aHeader.edgessaved);
-#endif
-        m_root = aHeader.root;
-        m_nbWords = aHeader.nwords;
-        m_nodesUsed = aHeader.nodesused;
-        m_edgesUsed = aHeader.edgesused;
-        m_nodesSaved = aHeader.nodessaved;
-        m_edgesSaved = aHeader.edgessaved;
-    }
+    m_root = ntohl(aHeader.root);
+    m_nbWords = ntohl(aHeader.nwords);
+    m_nodesUsed = ntohl(aHeader.nodesused);
+    m_edgesUsed = ntohl(aHeader.edgesused);
+    m_nodesSaved = ntohl(aHeader.nodessaved);
+    m_edgesSaved = ntohl(aHeader.edgessaved);
+
+    // After reading the old header, we now read the extension
+    Dict_header_ext aHeaderExt;
+    iStream.read((char*)&aHeaderExt, sizeof(Dict_header_ext));
+    if (iStream.gcount() != sizeof(Dict_header_ext))
+        throw DicException("Header::read: expected to read more bytes");
+
+    // Handle endianness in the extension
+    aHeaderExt.compressDate = ntohll(aHeaderExt.compressDate);
+    aHeaderExt.userHostSize = ntohl(aHeaderExt.userHostSize);
+    aHeaderExt.dicNameSize = ntohl(aHeaderExt.dicNameSize);
+    aHeaderExt.lettersSize = ntohl(aHeaderExt.lettersSize);
+    aHeaderExt.nbLetters = ntohl(aHeaderExt.nbLetters);
+    aHeaderExt.vowels = ntohll(aHeaderExt.vowels);
+    aHeaderExt.consonants = ntohll(aHeaderExt.consonants);
+
+    m_compressDate = aHeaderExt.compressDate;
+
+    if (aHeaderExt.algorithm == kDAWG)
+        m_type = kDAWG;
+    else if (aHeaderExt.algorithm == kGADDAG)
+        m_type = kGADDAG;
     else
+        throw DicException("Header::read: unrecognized algorithm type");
+
+    m_userHost = readFromUTF8(aHeaderExt.userHost, aHeaderExt.userHostSize,
+                              "user and host information");
+
+    // Convert the dictionary letters from UTF-8 to wchar_t*
+    m_dicName = readFromUTF8(aHeaderExt.dicName, aHeaderExt.dicNameSize,
+                             "dictionary name");
+
+    // Convert the dictionary letters from UTF-8 to wchar_t*
+    m_letters = readFromUTF8(aHeaderExt.letters, aHeaderExt.lettersSize,
+                             "dictionary letters");
+    // Safety check: correct number of letters?
+    if (m_letters.size() != aHeaderExt.nbLetters)
     {
-        m_root = ntohl(aHeader.root);
-        m_nbWords = ntohl(aHeader.nwords);
-        m_nodesUsed = ntohl(aHeader.nodesused);
-        m_edgesUsed = ntohl(aHeader.edgesused);
-        m_nodesSaved = ntohl(aHeader.nodessaved);
-        m_edgesSaved = ntohl(aHeader.edgessaved);
+        throw DicException("Header::read: inconsistent header");
     }
 
-    if (m_version == 0)
+    // Letters points and frequency
+    for (unsigned int i = 0; i < m_letters.size(); ++i)
     {
-        m_compressDate = 0;
-        m_userHost = convertToWc(_("Unknown (old format)"));
-        m_dicName = convertToWc(_("Unknown (old format)"));
-
-        // In version 0, the letters, points, frequency,
-        // vowels and consonants were hard-coded...
-        m_letters = convertToWc("ABCDEFGHIJKLMNOPQRSTUVWXYZ?");
-
-        static const uint8_t Frenchpoints[] =
-        {
-            // A B C D  E F G H I J  K L M N O P Q R S T U V  W  X  Y  Z ?
-               1,3,3,2, 1,4,2,4,1,8,10,1,2,1,1,3,8,1,1,1,1,4,10,10,10,10,0
-        };
-
-        static const uint8_t FrenchFrequency[] =
-        {
-            // A B C D  E F G H I J  K L M N O P Q R S T U V  W  X  Y  Z ?
-               9,2,2,3,15,2,2,2,8,1, 1,5,3,6,6,2,1,6,6,6,6,2, 1, 1, 1, 1,2
-        };
-
-        // The jokers and the 'Y' can be considered both as vowels or consonants
-        static const uint8_t FrenchVowels[] =
-        {
-            // A B C D  E F G H I J  K L M N O P Q R S T U V  W  X  Y  Z ?
-               1,0,0,0, 1,0,0,0,1,0, 0,0,0,0,1,0,0,0,0,0,1,0, 0, 0, 1, 0,1
-        };
-
-        static const uint8_t FrenchConsonants[] =
-        {
-            // A B C D  E F G H I J  K L M N O P Q R S T U V  W  X  Y  Z ?
-               0,1,1,1, 0,1,1,1,0,1, 1,1,1,1,0,1,1,1,1,1,0,1, 1, 1, 1, 1,1
-        };
-
-        for (unsigned int i = 0; i < m_letters.size(); ++i)
-        {
-            m_points.push_back(Frenchpoints[i]);
-            m_frequency.push_back(FrenchFrequency[i]);
-            m_vowels.push_back(FrenchVowels[i]);
-            m_consonants.push_back(FrenchConsonants[i]);
-        }
+        m_points.push_back(aHeaderExt.points[i]);
+        m_frequency.push_back(aHeaderExt.frequency[i]);
     }
-    else
+
+    // Vowels and consonants
+    for (unsigned int i = 0; i < m_letters.size(); ++i)
     {
-        // This header doesn't use the old serialization format, so read the
-        // extension as well
-        Dict_header_ext aHeaderExt;
-        iStream.read((char*)&aHeaderExt, sizeof(Dict_header_ext));
-        if (iStream.gcount() != sizeof(Dict_header_ext))
-            throw DicException("Header::read: expected to read more bytes");
-
-        // Handle endianness in the extension
-        aHeaderExt.compressDate = ntohll(aHeaderExt.compressDate);
-        aHeaderExt.userHostSize = ntohl(aHeaderExt.userHostSize);
-        aHeaderExt.dicNameSize = ntohl(aHeaderExt.dicNameSize);
-        aHeaderExt.lettersSize = ntohl(aHeaderExt.lettersSize);
-        aHeaderExt.nbLetters = ntohl(aHeaderExt.nbLetters);
-        aHeaderExt.vowels = ntohll(aHeaderExt.vowels);
-        aHeaderExt.consonants = ntohll(aHeaderExt.consonants);
-
-        m_compressDate = aHeaderExt.compressDate;
-
-        if (aHeaderExt.algorithm == kDAWG)
-            m_type = kDAWG;
-        else if (aHeaderExt.algorithm == kGADDAG)
-            m_type = kGADDAG;
-        else
-            throw DicException("Header::read: unrecognized algorithm type");
-
-        m_userHost = readFromUTF8(aHeaderExt.userHost, aHeaderExt.userHostSize,
-                                  "user and host information");
-
-        // Convert the dictionary letters from UTF-8 to wchar_t*
-        m_dicName = readFromUTF8(aHeaderExt.dicName, aHeaderExt.dicNameSize,
-                                 "dictionary name");
-
-        // Convert the dictionary letters from UTF-8 to wchar_t*
-        m_letters = readFromUTF8(aHeaderExt.letters, aHeaderExt.lettersSize,
-                                 "dictionary letters");
-        // Safety check: correct number of letters?
-        if (m_letters.size() != aHeaderExt.nbLetters)
-        {
-            throw DicException("Header::read: inconsistent header");
-        }
-
-        // Letters points and frequency
-        for (unsigned int i = 0; i < m_letters.size(); ++i)
-        {
-            m_points.push_back(aHeaderExt.points[i]);
-            m_frequency.push_back(aHeaderExt.frequency[i]);
-        }
-
-        // Vowels and consonants
-        for (unsigned int i = 0; i < m_letters.size(); ++i)
-        {
-            m_vowels.push_back(aHeaderExt.vowels & (1 << i));
-            m_consonants.push_back(aHeaderExt.consonants & (1 << i));
-        }
-
+        m_vowels.push_back(aHeaderExt.vowels & (1 << i));
+        m_consonants.push_back(aHeaderExt.consonants & (1 << i));
     }
 }
 
@@ -434,81 +378,70 @@ void Header::write(ostream &oStream) const
     if (!oStream.good())
         throw DicException("Header::write: error when writing to file");
 
-    if (m_version != 0)
+    Dict_header_ext aHeaderExt;
+    aHeaderExt.compressDate = m_compressDate;
+    aHeaderExt.userHostSize =
+        writeInUTF8(m_userHost, aHeaderExt.userHost,
+                    _MAX_USER_HOST_, "user and host information");
+    aHeaderExt.algorithm = m_type;
+
+    // Convert the dictionary name to UTF-8
+    aHeaderExt.dicNameSize =
+        writeInUTF8(m_dicName, aHeaderExt.dicName,
+                    _MAX_DIC_NAME_SIZE_, "dictionary name");
+
+    // Convert the dictionary letters to UTF-8
+    aHeaderExt.lettersSize =
+        writeInUTF8(m_letters, aHeaderExt.letters,
+                    _MAX_LETTERS_SIZE_, "dictionary letters");
+    aHeaderExt.nbLetters = (uint32_t)m_letters.size();
+
+    // Letters points and frequency
+    for (unsigned int i = 0; i < m_letters.size(); ++i)
     {
-        Dict_header_ext aHeaderExt;
-        aHeaderExt.compressDate = m_compressDate;
-        aHeaderExt.userHostSize =
-            writeInUTF8(m_userHost, aHeaderExt.userHost,
-                        _MAX_USER_HOST_, "user and host information");
-        aHeaderExt.algorithm = m_type;
-
-        // Convert the dictionary name to UTF-8
-        aHeaderExt.dicNameSize =
-            writeInUTF8(m_dicName, aHeaderExt.dicName,
-                        _MAX_DIC_NAME_SIZE_, "dictionary name");
-
-        // Convert the dictionary letters to UTF-8
-        aHeaderExt.lettersSize =
-            writeInUTF8(m_letters, aHeaderExt.letters,
-                        _MAX_LETTERS_SIZE_, "dictionary letters");
-        aHeaderExt.nbLetters = (uint32_t)m_letters.size();
-
-        // Letters points and frequency
-        for (unsigned int i = 0; i < m_letters.size(); ++i)
-        {
-            aHeaderExt.points[i] = m_points[i];
-            aHeaderExt.frequency[i] = m_frequency[i];
-        }
-
-        // Vowels and consonants
-        aHeaderExt.vowels = 0;
-        aHeaderExt.consonants = 0;
-        for (unsigned int i = 0; i < m_letters.size(); ++i)
-        {
-            if (m_vowels[i])
-                aHeaderExt.vowels |= 1 << i;
-            if (m_consonants[i])
-                aHeaderExt.consonants |= 1 << i;
-        }
-
-        // Handle endianness in the extension
-        aHeaderExt.userHostSize = htonl(aHeaderExt.userHostSize);
-        aHeaderExt.compressDate = htonll(aHeaderExt.compressDate);
-        aHeaderExt.dicNameSize = htonl(aHeaderExt.dicNameSize);
-        aHeaderExt.lettersSize = htonl(aHeaderExt.lettersSize);
-        aHeaderExt.nbLetters = htonl(aHeaderExt.nbLetters);
-        aHeaderExt.vowels = htonll(aHeaderExt.vowels);
-        aHeaderExt.consonants = htonll(aHeaderExt.consonants);
-
-        // Write the extension
-        oStream.write((char*)&aHeaderExt, sizeof(Dict_header_ext));
-        if (!oStream.good())
-            throw DicException("Header::write: error when writing to file");
+        aHeaderExt.points[i] = m_points[i];
+        aHeaderExt.frequency[i] = m_frequency[i];
     }
+
+    // Vowels and consonants
+    aHeaderExt.vowels = 0;
+    aHeaderExt.consonants = 0;
+    for (unsigned int i = 0; i < m_letters.size(); ++i)
+    {
+        if (m_vowels[i])
+            aHeaderExt.vowels |= 1 << i;
+        if (m_consonants[i])
+            aHeaderExt.consonants |= 1 << i;
+    }
+
+    // Handle endianness in the extension
+    aHeaderExt.userHostSize = htonl(aHeaderExt.userHostSize);
+    aHeaderExt.compressDate = htonll(aHeaderExt.compressDate);
+    aHeaderExt.dicNameSize = htonl(aHeaderExt.dicNameSize);
+    aHeaderExt.lettersSize = htonl(aHeaderExt.lettersSize);
+    aHeaderExt.nbLetters = htonl(aHeaderExt.nbLetters);
+    aHeaderExt.vowels = htonll(aHeaderExt.vowels);
+    aHeaderExt.consonants = htonll(aHeaderExt.consonants);
+
+    // Write the extension
+    oStream.write((char*)&aHeaderExt, sizeof(Dict_header_ext));
+    if (!oStream.good())
+        throw DicException("Header::write: error when writing to file");
 }
 
 
 void Header::print() const
 {
     printf(_("dictionary name: %s\n"), convertToMb(m_dicName).c_str());
-    if (m_version)
-    {
-        char buf[50];
-        strftime(buf, sizeof(buf), "%c", gmtime(&m_compressDate));
-        printf(_("compressed on: %s\n"), buf);
-    }
-    else
-    {
-        printf(_("compressed on: Unknown date (old format)\n"));
-    }
+    char buf[50];
+    strftime(buf, sizeof(buf), "%c", gmtime(&m_compressDate));
+    printf(_("compressed on: %s\n"), buf);
     printf(_("compressed using a binary compiled by: %s\n"), convertToMb(m_userHost).c_str());
     printf(_("dictionary type: %s\n"), m_type == kDAWG ? "DAWG" : "GADDAG");
     printf(_("letters: %s\n"), convertToMb(m_letters).c_str());
     printf(_("number of letters: %lu\n"), (long unsigned int)m_letters.size());
     printf(_("number of words: %d\n"), m_nbWords);
-    long unsigned int size =
-        sizeof(Dict_header_old) + (m_version ? sizeof(Dict_header_ext) : 0);
+    long unsigned int size = sizeof(Dict_header_old) + sizeof(Dict_header_ext);
     printf(_("header size: %lu bytes\n"), size);
     printf(_("root: %d (edge)\n"), m_root);
     printf(_("nodes: %d used + %d saved\n"), m_nodesUsed, m_nodesSaved);
