@@ -20,14 +20,17 @@
  *****************************************************************************/
 
 #include <wctype.h>
+
 #include "dic.h"
+
+#include "board.h"
+#include "board_search.h"
 #include "tile.h"
 #include "round.h"
-#include "bag.h"
 #include "rack.h"
 #include "results.h"
-#include "board.h"
 #include "debug.h"
+// FIXME: should not be included here
 #include "game.h"
 
 #define oo 0
@@ -254,11 +257,11 @@ void Board::removeRound(const Dictionary &iDic, const Round &iRound)
 
 /* XXX: There is duplicated code with board_search.c.
  * We could probably factorize something... */
-int Board::checkRoundAux(Matrix<Tile> &iTilesMx,
-                         Matrix<Cross> &iCrossMx,
-                         Matrix<int> &iPointsMx,
-                         Matrix<bool> &iJokerMx,
-                         Round &iRound)
+int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
+                         const Matrix<Cross> &iCrossMx,
+                         const Matrix<int> &iPointsMx,
+                         const Matrix<bool> &iJokerMx,
+                         Round &iRound) const
 {
     Tile t;
     int l, p;
@@ -368,7 +371,7 @@ int Board::checkRoundAux(Matrix<Tile> &iTilesMx,
 }
 
 
-int Board::checkRound(Round &iRound)
+int Board::checkRound(Round &iRound) const
 {
     if (iRound.getCoord().getDir() == Coord::HORIZONTAL)
     {
@@ -510,29 +513,45 @@ void Board::checkDouble()
         {
             if (m_tilesRow[row][col] != m_tilesCol[col][row])
                 printf("tiles diff %d %d\n", row, col);
-
-            // The crossckecks and the points have no reason to be the same
-            // in both directions
-            /*
-            if (m_crossRow[row][col] != m_crossCol[col][row])
-            {
-                printf("cross diff %d %d\n",row,col);
-            }
-
-            if (m_pointRow[row][col] != m_pointCol[col][row])
-                printf("point diff %d %d\n",row,col);
-            */
-
             if (m_jokerRow[row][col] != m_jokerCol[col][row])
                 printf("joker diff %d %d\n", row, col);
+            // The crossckecks and the points have no reason to be the same
+            // in both directions
         }
     }
 }
 #endif
 
-/// Local Variables:
-/// mode: c++
-/// mode: hs-minor
-/// c-basic-offset: 4
-/// indent-tabs-mode: nil
-/// End:
+
+void Board::search(const Dictionary &iDic,
+                   const Rack &iRack,
+                   Results &oResults) const
+{
+    // Create a copy of the rack to avoid modifying the given one
+    Rack copyRack = iRack;
+
+    // Search horizontal words
+    BoardSearch horizSearch(iDic, m_tilesRow, m_crossRow,
+                            m_pointRow, m_jokerRow);
+    horizSearch.search(copyRack, oResults, Coord::HORIZONTAL);
+
+    // Search vertical words
+    BoardSearch vertSearch(iDic, m_tilesCol, m_crossCol,
+                            m_pointCol, m_jokerCol);
+    vertSearch.search(copyRack, oResults, Coord::VERTICAL);
+}
+
+
+void Board::searchFirst(const Dictionary &iDic,
+                        const Rack &iRack,
+                        Results &oResults) const
+{
+    // Create a copy of the rack to avoid modifying the given one
+    Rack copyRack = iRack;
+
+    // Search horizontal words
+    BoardSearch horizSearch(iDic, m_tilesRow, m_crossRow,
+                            m_pointRow, m_jokerRow, true);
+    horizSearch.search(copyRack, oResults, Coord::HORIZONTAL);
+}
+
