@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Eliot
- * Copyright (C) 2005-2007 Olivier Teulière
+ * Copyright (C) 2005-2008 Olivier Teulière
  * Authors: Olivier Teulière <ipkiss @@ gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,8 @@
 #define _FREEGAME_H_
 
 #include "game.h"
-#include "tile.h"
+
+class Player;
 
 using std::string;
 using std::wstring;
@@ -51,10 +52,8 @@ public:
      *************************/
     /**
      * Start the game.
-     * Possible return values:
-     *  0: everything went fine
      */
-    virtual int start();
+    virtual void start();
 
     /**
      * See description of Game::play() for the possible return values.
@@ -86,6 +85,9 @@ private:
     /// Make the AI player whose ID is p play its turn
     void playAI(unsigned int p);
 
+    /// Record a player move
+    void recordPlayerMove(const Move &iMove, Player &ioPlayer, bool isForHuman);
+
     /// Finish the current turn
     int endTurn();
 
@@ -96,14 +98,8 @@ private:
      * Check whether it is legal to change the letters of iToChange.
      * The return codes are the same as the ones on the pass() method
      */
-    int checkPass(const wstring &iToChange, unsigned int p) const;
+    int checkPass(const Player &iPlayer, const wstring &iToChange) const;
 };
 
 #endif /* _FREEGAME_H_ */
 
-/// Local Variables:
-/// mode: c++
-/// mode: hs-minor
-/// c-basic-offset: 4
-/// indent-tabs-mode: nil
-/// End:
