@@ -19,27 +19,20 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *****************************************************************************/
 
-/**
- *  \file   turn.cpp
- *  \brief  Game turn (= id + pldrack + move)
- *  \author Antoine Fraboulet
- *  \date   2005
- */
-
 #include "turn.h"
 
 
 // FIXME: move set to an invalid value. It would be better to get rid of this
 // constructor completely
 Turn::Turn()
-    : m_num(0), m_playerId(0), m_move(L"", L"")
+    : m_playerId(0), m_move(L"", L"")
 {
 }
 
 
-Turn::Turn(unsigned int iNum, unsigned int iPlayerId,
-           const PlayedRack& iPldRack, const Move& iMove)
-    : m_num(iNum), m_playerId(iPlayerId), m_pldrack(iPldRack), m_move(iMove)
+Turn::Turn(unsigned int iPlayerId, const PlayedRack& iPldRack,
+           const Move& iMove)
+    : m_playerId(iPlayerId), m_pldrack(iPldRack), m_move(iMove)
 {
 }
 
@@ -55,9 +48,3 @@ wstring Turn::toString(bool iShowExtraSigns) const
     return rs;
 }
 
-/// Local Variables:
-/// mode: c++
-/// mode: hs-minor
-/// c-basic-offset: 4
-/// indent-tabs-mode: nil
-/// End:
