@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'board_widget.h'
 **
-** Created: Sun Jan 25 00:15:20 2009
+** Created: Sat Feb 21 18:01:58 2009
 **      by: The Qt Meta Object Compiler version 59 (Qt 4.4.3)
 **
 ** WARNING! All changes made in this file will be lost!
@@ -23,20 +23,21 @@ static const uint qt_meta_data_BoardWidget[] = {
        1,       // revision
        0,       // classname
        0,    0, // classinfo
-       2,   10, // methods
+       3,   10, // methods
        0,    0, // properties
        0,    0, // enums/sets
 
  // slots: signature, parameters, type, tag, flags
       19,   13,   12,   12, 0x0a,
       46,   12,   12,   12, 0x0a,
+      63,   56,   12,   12, 0x08,
 
        0        // eod
 };
 
 static const char qt_meta_stringdata_BoardWidget[] = {
     "BoardWidget\0\0iGame\0setGame(const PublicGame*)\0"
-    "refresh()\0"
+    "refresh()\0iCoord\0updateArrow(Coord)\0"
 };
 
 const QMetaObject BoardWidget::staticMetaObject = {
@@ -66,8 +67,9 @@ int BoardWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         switch (_id) {
         case 0: setGame((*reinterpret_cast< const PublicGame*(*)>(_a[1]))); break;
         case 1: refresh(); break;
+        case 2: updateArrow((*reinterpret_cast< const Coord(*)>(_a[1]))); break;
         }
-        _id -= 2;
+        _id -= 3;
     }
     return _id;
 }
