@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'player_widget.h'
 **
-** Created: Sun Jan 25 00:15:20 2009
+** Created: Sat Feb 21 18:01:58 2009
 **      by: The Qt Meta Object Compiler version 59 (Qt 4.4.3)
 **
 ** WARNING! All changes made in this file will be lost!
@@ -23,7 +23,7 @@ static const uint qt_meta_data_PlayerWidget[] = {
        1,       // revision
        0,       // classname
        0,    0, // classinfo
-      14,   10, // methods
+       9,   10, // methods
        0,    0, // properties
        0,    0, // enums/sets
 
@@ -36,14 +36,9 @@ static const uint qt_meta_data_PlayerWidget[] = {
       76,   13,   13,   13, 0x0a,
       86,   13,   13,   13, 0x08,
      117,   13,   13,   13, 0x08,
-     145,   13,   13,   13, 0x08,
+     147,   13,   13,   13, 0x08,
      175,   13,   13,   13, 0x08,
-     203,   13,   13,   13, 0x08,
-     233,   13,   13,   13, 0x08,
-     265,   13,   13,   13, 0x08,
-     297,   13,   13,   13, 0x08,
-     329,   13,   13,   13, 0x08,
-     363,   13,   13,   13, 0x08,
+     207,   13,   13,   13, 0x08,
 
        0        // eod
 };
@@ -52,14 +47,9 @@ static const char qt_meta_stringdata_PlayerWidget[] = {
     "PlayerWidget\0\0gameUpdated()\0iMsg\0"
     "notifyProblem(QString)\0notifyInfo(QString)\0"
     "refresh()\0on_pushButtonShuffle_clicked()\0"
-    "on_pushButtonPlay_clicked()\0"
     "on_pushButtonChange_clicked()\0"
     "on_pushButtonPass_clicked()\0"
-    "on_lineEditPlay_textChanged()\0"
-    "on_lineEditCoords_textChanged()\0"
     "on_lineEditChange_textChanged()\0"
-    "on_lineEditPlay_returnPressed()\0"
-    "on_lineEditCoords_returnPressed()\0"
     "on_lineEditChange_returnPressed()\0"
 };
 
@@ -93,17 +83,12 @@ int PlayerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         case 2: notifyInfo((*reinterpret_cast< QString(*)>(_a[1]))); break;
         case 3: refresh(); break;
         case 4: on_pushButtonShuffle_clicked(); break;
-        case 5: on_pushButtonPlay_clicked(); break;
-        case 6: on_pushButtonChange_clicked(); break;
-        case 7: on_pushButtonPass_clicked(); break;
-        case 8: on_lineEditPlay_textChanged(); break;
-        case 9: on_lineEditCoords_textChanged(); break;
-        case 10: on_lineEditChange_textChanged(); break;
-        case 11: on_lineEditPlay_returnPressed(); break;
-        case 12: on_lineEditCoords_returnPressed(); break;
-        case 13: on_lineEditChange_returnPressed(); break;
+        case 5: on_pushButtonChange_clicked(); break;
+        case 6: on_pushButtonPass_clicked(); break;
+        case 7: on_lineEditChange_textChanged(); break;
+        case 8: on_lineEditChange_returnPressed(); break;
         }
-        _id -= 14;
+        _id -= 9;
     }
     return _id;
 }
