@@ -1,7 +1,7 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'training_widget.h'
 **
-** Created: Sun Jan 25 00:15:20 2009
+** Created: Sat Feb 21 18:01:58 2009
 **      by: The Qt Meta Object Compiler version 59 (Qt 4.4.3)
 **
 ** WARNING! All changes made in this file will be lost!
@@ -23,7 +23,7 @@ static const uint qt_meta_data_TrainingWidget[] = {
        1,       // revision
        0,       // classname
        0,    0, // classinfo
-      14,   10, // methods
+      13,   10, // methods
        0,    0, // properties
        0,    0, // enums/sets
 
@@ -34,16 +34,15 @@ static const uint qt_meta_data_TrainingWidget[] = {
       84,   78,   15,   15, 0x05,
 
  // slots: signature, parameters, type, tag, flags
-     111,  105,   15,   15, 0x0a,
-     132,   15,   15,   15, 0x0a,
-     144,  142,   15,   15, 0x08,
-     192,  142,   15,   15, 0x08,
-     241,  235,   15,   15, 0x08,
-     277,   15,   15,   15, 0x08,
-     305,   15,   15,   15, 0x08,
-     339,   15,   15,   15, 0x08,
-     369,   15,   15,   15, 0x08,
-     404,  397,   15,   15, 0x08,
+     105,   15,   15,   15, 0x0a,
+     117,  115,   15,   15, 0x08,
+     165,  115,   15,   15, 0x08,
+     214,  208,   15,   15, 0x08,
+     250,   15,   15,   15, 0x08,
+     278,   15,   15,   15, 0x08,
+     312,   15,   15,   15, 0x08,
+     342,   15,   15,   15, 0x08,
+     385,  378,   15,   15, 0x08,
 
        0        // eod
 };
@@ -51,16 +50,15 @@ static const uint qt_meta_data_TrainingWidget[] = {
 static const char qt_meta_stringdata_TrainingWidget[] = {
     "TrainingWidget\0\0gameUpdated()\0iMsg\0"
     "notifyProblem(QString)\0notifyInfo(QString)\0"
-    "iRack\0rackUpdated(QString)\0iGame\0"
-    "setGame(PublicGame*)\0refresh()\0,\0"
-    "enablePlayButton(QItemSelection,QItemSelection)\0"
+    "iRack\0rackUpdated(QString)\0refresh()\0"
+    ",\0enablePlayButton(QItemSelection,QItemSelection)\0"
     "showPreview(QItemSelection,QItemSelection)\0"
     "iText\0on_lineEditRack_textEdited(QString)\0"
     "on_pushButtonRack_clicked()\0"
     "on_pushButtonComplement_clicked()\0"
     "on_pushButtonSearch_clicked()\0"
-    "on_pushButtonPlay_clicked()\0iIndex\0"
-    "on_treeViewResults_doubleClicked(QModelIndex)\0"
+    "on_pushButtonPlaySelected_clicked()\0"
+    "iIndex\0on_treeViewResults_doubleClicked(QModelIndex)\0"
 };
 
 const QMetaObject TrainingWidget::staticMetaObject = {
@@ -92,18 +90,17 @@ int TrainingWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         case 1: notifyProblem((*reinterpret_cast< QString(*)>(_a[1]))); break;
         case 2: notifyInfo((*reinterpret_cast< QString(*)>(_a[1]))); break;
         case 3: rackUpdated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 4: setGame((*reinterpret_cast< PublicGame*(*)>(_a[1]))); break;
-        case 5: refresh(); break;
-        case 6: enablePlayButton((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
-        case 7: showPreview((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
-        case 8: on_lineEditRack_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
-        case 9: on_pushButtonRack_clicked(); break;
-        case 10: on_pushButtonComplement_clicked(); break;
-        case 11: on_pushButtonSearch_clicked(); break;
-        case 12: on_pushButtonPlay_clicked(); break;
-        case 13: on_treeViewResults_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
+        case 4: refresh(); break;
+        case 5: enablePlayButton((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
+        case 6: showPreview((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
+        case 7: on_lineEditRack_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
+        case 8: on_pushButtonRack_clicked(); break;
+        case 9: on_pushButtonComplement_clicked(); break;
+        case 10: on_pushButtonSearch_clicked(); break;
+        case 11: on_pushButtonPlaySelected_clicked(); break;
+        case 12: on_treeViewResults_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
         }
-        _id -= 14;
+        _id -= 13;
     }
     return _id;
 }
